# Reference

<!-- DO NOT EDIT: This document was generated by Puppet Strings -->

## Table of Contents

### Classes

#### Public Classes

* [`candlepin`](#candlepin): Manage a Candlepin server
* [`candlepin::repo`](#candlepinrepo): Manage the yum repository

#### Private Classes

* `candlepin::artemis`: Configuration for Artemis
* `candlepin::config`: Configuration for Candlepin
* `candlepin::database::mysql`: Candlepin Database Setup using Mysql
* `candlepin::database::postgresql`: Candlepin Database Setup using Postgresql
* `candlepin::install`: Candlepin installation packages
* `candlepin::params`: Candlepin params
* `candlepin::service`: Candlepin Service and Initialization

### Resource types

* [`cpdb_create`](#cpdb_create): Runs cpdb create command to setup database schema
* [`cpdb_update`](#cpdb_update): Runs cpdb update command to migrate the database

## Classes

### <a name="candlepin"></a>`candlepin`

Manage a Candlepin server

#### Parameters

The following parameters are available in the `candlepin` class:

* [`oauth_key`](#oauth_key)
* [`oauth_secret`](#oauth_secret)
* [`manage_db`](#manage_db)
* [`init_db`](#init_db)
* [`db_type`](#db_type)
* [`db_host`](#db_host)
* [`db_port`](#db_port)
* [`db_ssl`](#db_ssl)
* [`db_ssl_verify`](#db_ssl_verify)
* [`db_ssl_ca`](#db_ssl_ca)
* [`db_name`](#db_name)
* [`db_user`](#db_user)
* [`db_password`](#db_password)
* [`user_groups`](#user_groups)
* [`log_dir`](#log_dir)
* [`env_filtering_enabled`](#env_filtering_enabled)
* [`keystore_file`](#keystore_file)
* [`keystore_password`](#keystore_password)
* [`keystore_type`](#keystore_type)
* [`truststore_file`](#truststore_file)
* [`truststore_password`](#truststore_password)
* [`ca_key`](#ca_key)
* [`ca_cert`](#ca_cert)
* [`ca_key_password`](#ca_key_password)
* [`ciphers`](#ciphers)
* [`tls_versions`](#tls_versions)
* [`version`](#version)
* [`java_package`](#java_package)
* [`wget_version`](#wget_version)
* [`run_init`](#run_init)
* [`adapter_module`](#adapter_module)
* [`enable_basic_auth`](#enable_basic_auth)
* [`enable_trusted_auth`](#enable_trusted_auth)
* [`consumer_system_name_pattern`](#consumer_system_name_pattern)
* [`enable_hbm2ddl_validate`](#enable_hbm2ddl_validate)
* [`ssl_port`](#ssl_port)
* [`host`](#host)
* [`candlepin_conf_file`](#candlepin_conf_file)
* [`tomcat_base`](#tomcat_base)
* [`java_home`](#java_home)
* [`catalina_home`](#catalina_home)
* [`catalina_tmpdir`](#catalina_tmpdir)
* [`java_opts`](#java_opts)
* [`lang`](#lang)
* [`security_manager`](#security_manager)
* [`shutdown_wait`](#shutdown_wait)
* [`expired_pools_schedule`](#expired_pools_schedule)
* [`artemis_port`](#artemis_port)
* [`artemis_host`](#artemis_host)
* [`artemis_client_dn`](#artemis_client_dn)
* [`broker_config_file`](#broker_config_file)
* [`user`](#user)
* [`group`](#group)
* [`disable_fips`](#disable_fips)

##### <a name="oauth_key"></a>`oauth_key`

Data type: `String`

The OAuth key for talking to the candlepin API

Default value: `'candlepin'`

##### <a name="oauth_secret"></a>`oauth_secret`

Data type: `String`

The OAuth secret for talking to the candlepin API

Default value: `'candlepin'`

##### <a name="manage_db"></a>`manage_db`

Data type: `Boolean`

Whether a database should be installed, this includes db creation and user

Default value: ``true``

##### <a name="init_db"></a>`init_db`

Data type: `Boolean`

Whether a database should be initialised.

Default value: ``true``

##### <a name="db_type"></a>`db_type`

Data type: `Enum['postgresql','mysql']`

The type of database Candlepin will be connecting too.

Default value: `'postgresql'`

##### <a name="db_host"></a>`db_host`

Data type: `Stdlib::Host`

Hostname of database server.

Default value: `'localhost'`

##### <a name="db_port"></a>`db_port`

Data type: `Optional[Stdlib::Port]`

Port the database listens on. Only needs to be provided if different from
standard port of the :db_type.

Default value: ``undef``

##### <a name="db_ssl"></a>`db_ssl`

Data type: `Boolean`

Boolean indicating if the connection to the database should be over an SSL
connection.

Default value: ``false``

##### <a name="db_ssl_verify"></a>`db_ssl_verify`

Data type: `Boolean`

Boolean indicating if the SSL connection to the database should be verified

Default value: ``true``

##### <a name="db_ssl_ca"></a>`db_ssl_ca`

Data type: `Optional[Stdlib::Absolutepath]`

The CA certificate to verify the SSL connection to the database with

Default value: ``undef``

##### <a name="db_name"></a>`db_name`

Data type: `String`

The name of the Candlepin database

Default value: `'candlepin'`

##### <a name="db_user"></a>`db_user`

Data type: `String`

The Candlepin database username

Default value: `'candlepin'`

##### <a name="db_password"></a>`db_password`

Data type: `Variant[Sensitive[String], String]`

The Candlepin database password

Default value: `$candlepin::params::db_password`

##### <a name="user_groups"></a>`user_groups`

Data type: `Variant[Array[String], String]`

The user groups for the Candlepin tomcat user

Default value: `[]`

##### <a name="log_dir"></a>`log_dir`

Data type: `Stdlib::Absolutepath`

Directory for Candlepin logs

Default value: `'/var/log/candlepin'`

##### <a name="env_filtering_enabled"></a>`env_filtering_enabled`

Data type: `Boolean`

If subscription filtering is done on a per environment basis

Default value: ``true``

##### <a name="keystore_file"></a>`keystore_file`

Data type: `Stdlib::Absolutepath`

Tomcat keystore file to use

Default value: `'/etc/candlepin/certs/keystore'`

##### <a name="keystore_password"></a>`keystore_password`

Data type: `Optional[Variant[Sensitive[String], String]]`

Password for keystore being used with Tomcat

Default value: ``undef``

##### <a name="keystore_type"></a>`keystore_type`

Data type: `String`

Keystore type

Default value: `'PKCS12'`

##### <a name="truststore_file"></a>`truststore_file`

Data type: `Stdlib::Absolutepath`

Truststore file to use for Tomcat and Artemis

Default value: `'/etc/candlepin/certs/truststore'`

##### <a name="truststore_password"></a>`truststore_password`

Data type: `Optional[Variant[Sensitive[String], String]]`

Password for truststore being used with Tomcat and Artemis

Default value: ``undef``

##### <a name="ca_key"></a>`ca_key`

Data type: `Stdlib::Absolutepath`

CA key file to use

Default value: `'/etc/candlepin/certs/candlepin-ca.key'`

##### <a name="ca_cert"></a>`ca_cert`

Data type: `Stdlib::Absolutepath`

CA certificate file to use

Default value: `'/etc/candlepin/certs/candlepin-ca.crt'`

##### <a name="ca_key_password"></a>`ca_key_password`

Data type: `Optional[Variant[Sensitive[String], String]]`

CA key password

Default value: ``undef``

##### <a name="ciphers"></a>`ciphers`

Data type: `Array[String]`

Allowed ciphers for ssl connection

Default value: `$candlepin::params::ciphers`

##### <a name="tls_versions"></a>`tls_versions`

Data type: `Array[String]`

Allowed versions of TLS, for example 1.1, 1.2, etc

Default value: `['1.2']`

##### <a name="version"></a>`version`

Data type: `String`

Version of Candlepin to install

Default value: `'present'`

##### <a name="java_package"></a>`java_package`

Data type: `Optional[String[1]]`

Use in conjunction with java_home to specify the JVM used by Tomcat

Default value: ``undef``

##### <a name="wget_version"></a>`wget_version`

Data type: `String`

Version of wget to install

Default value: `'present'`

##### <a name="run_init"></a>`run_init`

Data type: `Boolean`

If the init api should be called on Candlepin

Default value: ``false``

##### <a name="adapter_module"></a>`adapter_module`

Data type: `Optional[String]`

Candlepin adapter implementations to inject into the java runtime

Default value: ``undef``

##### <a name="enable_basic_auth"></a>`enable_basic_auth`

Data type: `Boolean`

Whether to enable HTTP basic auth

Default value: ``true``

##### <a name="enable_trusted_auth"></a>`enable_trusted_auth`

Data type: `Boolean`

Whether to enable trusted auth

Default value: ``false``

##### <a name="consumer_system_name_pattern"></a>`consumer_system_name_pattern`

Data type: `Optional[String]`

Regex that consistutes a valid consumer name

Default value: ``undef``

##### <a name="enable_hbm2ddl_validate"></a>`enable_hbm2ddl_validate`

Data type: `Boolean`

If true will perform a schema check to ensure compliance with the models.
Disabling this feature may be required if modifications are required to schema

Default value: ``true``

##### <a name="ssl_port"></a>`ssl_port`

Data type: `Stdlib::Port`

Port to deploy SSL enabled Tomcat server on

Default value: `8443`

##### <a name="host"></a>`host`

Data type: `Stdlib::Host`

Host to deploy Tomcat server on; defaults to localhost

Default value: `'localhost'`

##### <a name="candlepin_conf_file"></a>`candlepin_conf_file`

Data type: `Stdlib::Absolutepath`

Configuration file location for candlepin

Default value: `'/etc/candlepin/candlepin.conf'`

##### <a name="tomcat_base"></a>`tomcat_base`

Data type: `Stdlib::Absolutepath`

In new-style instances, if CATALINA_BASE isn't specified, it will be
constructed by joining TOMCATS_BASE and NAME.

Default value: `'/var/lib/tomcats/'`

##### <a name="java_home"></a>`java_home`

Data type: `Stdlib::Absolutepath`

Where your java installation lives

Default value: `'/usr/lib/jvm/jre'`

##### <a name="catalina_home"></a>`catalina_home`

Data type: `Stdlib::Absolutepath`

Where your tomcat installation lives

Default value: `'/usr/share/tomcat'`

##### <a name="catalina_tmpdir"></a>`catalina_tmpdir`

Data type: `Stdlib::Absolutepath`

System-wide tmp

Default value: `'/var/cache/tomcat/temp'`

##### <a name="java_opts"></a>`java_opts`

Data type: `String`

Java Parameters

Default value: `'-Xms1024m -Xmx4096m'`

##### <a name="lang"></a>`lang`

Data type: `Optional[String]`

Tomcat locale setting

Default value: ``undef``

##### <a name="security_manager"></a>`security_manager`

Data type: `Boolean`

Run tomcat under the Java Security Manager

Default value: ``false``

##### <a name="shutdown_wait"></a>`shutdown_wait`

Data type: `Optional[Integer[0]]`

Time to wait in seconds, before killing process

Default value: ``undef``

##### <a name="expired_pools_schedule"></a>`expired_pools_schedule`

Data type: `String`

Quartz schedule notation for how often to run the ExpiredPoolsJob

Default value: `'0 0 0 * * ?'`

##### <a name="artemis_port"></a>`artemis_port`

Data type: `Stdlib::Port`

Port to expose Artemis on

Default value: `61613`

##### <a name="artemis_host"></a>`artemis_host`

Data type: `Stdlib::Host`

Host address to have Artemis listen on; defaults to localhost

Default value: `'localhost'`

##### <a name="artemis_client_dn"></a>`artemis_client_dn`

Data type: `Variant[Deferred, String]`

Full DN for the client certificate used to talk to Artemis

Default value: `'CN=ActiveMQ Artemis Client, OU=Artemis, O=ActiveMQ, L=AMQ, ST=AMQ, C=AMQ'`

##### <a name="broker_config_file"></a>`broker_config_file`

Data type: `Stdlib::Absolutepath`

Config file for Artemis

Default value: `'/etc/candlepin/broker.xml'`

##### <a name="user"></a>`user`

Data type: `String`

User under which Candlepin will run

Default value: `'tomcat'`

##### <a name="group"></a>`group`

Data type: `String`

Primary group for the Candlepin user

Default value: `'tomcat'`

##### <a name="disable_fips"></a>`disable_fips`

Data type: `Boolean`

Disable FIPS within the Java environment for Tomcat explicitly.
When set to false, no flag is added. Then on FIPS enabled systems, a Candlepin build that supports FIPS is required.

Default value: ``true``

### <a name="candlepinrepo"></a>`candlepin::repo`

Manage the yum repository

#### Parameters

The following parameters are available in the `candlepin::repo` class:

* [`version`](#version)
* [`dist`](#dist)
* [`gpgcheck`](#gpgcheck)
* [`gpgkey`](#gpgkey)

##### <a name="version"></a>`version`

Data type: `String`

Which yum repository to install. For example latest or 3.3. Note that the
versions are Katello releases.

##### <a name="dist"></a>`dist`

Data type: `String`

The dist code to use in the URL

Default value: `"el${facts['os']['release']['major']}"`

##### <a name="gpgcheck"></a>`gpgcheck`

Data type: `Boolean`

Whether to check the GPG signatures

Default value: ``false``

##### <a name="gpgkey"></a>`gpgkey`

Data type: `Optional[String]`

The GPG key to use

Default value: ``undef``

## Resource types

### <a name="cpdb_create"></a>`cpdb_create`

Runs cpdb create command to setup database schema

#### Properties

The following properties are available in the `cpdb_create` type.

##### `ensure`

Valid values: `present`, `absent`

The basic property that the resource should be in.

Default value: `present`

#### Parameters

The following parameters are available in the `cpdb_create` type.

* [`db_host`](#db_host)
* [`db_name`](#db_name)
* [`db_password`](#db_password)
* [`db_port`](#db_port)
* [`db_user`](#db_user)
* [`provider`](#provider)
* [`ssl_options`](#ssl_options)

##### <a name="db_host"></a>`db_host`

Database host

##### <a name="db_name"></a>`db_name`


##### <a name="db_password"></a>`db_password`

Password of the database user

##### <a name="db_port"></a>`db_port`

Database port

##### <a name="db_user"></a>`db_user`

User to connect to the database with

##### <a name="provider"></a>`provider`

The specific backend to use for this `cpdb_create` resource. You will seldom need to specify this --- Puppet will
usually discover the appropriate provider for your platform.

##### <a name="ssl_options"></a>`ssl_options`

SSL options if necessary for connecting to the database

### <a name="cpdb_update"></a>`cpdb_update`

Runs cpdb update command to migrate the database

#### Properties

The following properties are available in the `cpdb_update` type.

##### `ensure`

Valid values: `present`, `absent`

The basic property that the resource should be in.

Default value: `present`

#### Parameters

The following parameters are available in the `cpdb_update` type.

* [`db_host`](#db_host)
* [`db_name`](#db_name)
* [`db_password`](#db_password)
* [`db_port`](#db_port)
* [`db_user`](#db_user)
* [`provider`](#provider)
* [`ssl_options`](#ssl_options)

##### <a name="db_host"></a>`db_host`

Database host

##### <a name="db_name"></a>`db_name`


##### <a name="db_password"></a>`db_password`

Password of the database user

##### <a name="db_port"></a>`db_port`

Database port

##### <a name="db_user"></a>`db_user`

User to connect to the database with

##### <a name="provider"></a>`provider`

The specific backend to use for this `cpdb_update` resource. You will seldom need to specify this --- Puppet will
usually discover the appropriate provider for your platform.

##### <a name="ssl_options"></a>`ssl_options`

SSL options if necessary for connecting to the database

